@@ -17,6 +17,7 @@ require 'gem2deb'
 require 'gem2deb/banner'
 require 'gem2deb/installer'
 require 'gem2deb/make'
+require 'gem2deb/source'
 require 'find'
 require 'fileutils'
 
@@ -33,6 +34,7 @@ module Gem2Deb
       @verbose = true
       @skip_checks = nil
       @installer_class = Gem2Deb::Installer
+      @source = Gem2Deb::Source.new
     end
 
     def clean
@@ -41,7 +43,7 @@ module Gem2Deb
       make.clean
 
       installers.each do |installer|
-        installer.run_make_clean_on_extensions
+        installer.clean
       end
     end
 
@@ -70,7 +72,7 @@ module Gem2Deb
 
       dh_auto_install_destdir = argv.first
 
-      make.install(destdir_for(packages.first[:binary_package], dh_auto_install_destdir))
+      make.install(destdir_for(@source.packages.first[:binary_package], dh_auto_install_destdir))
 
       ruby_versions.each do |version|
         if !SUPPORTED_RUBY_VERSIONS.include?(version)
@@ -81,13 +83,7 @@ module Gem2Deb
 
       installers.each do |installer|
         installer.destdir_base = destdir_for(installer.binary_package, dh_auto_install_destdir)
-        installer.install_files_and_build_extensions
-        installer.update_shebangs
-      end
-
-      installers.each do |installer|
-        installer.install_substvars
-        installer.install_gemspec
+        installer.install
       end
 
       run_tests
@@ -154,7 +150,7 @@ module Gem2Deb
     def skip_checks?
       if @skip_checks.nil?
         if ENV['DEB_BUILD_OPTIONS'] && ENV['DEB_BUILD_OPTIONS'].split(' ').include?('nocheck')
-          puts "DEB_BUILD_OPTIONS includes nocheck, skipping all checks (test suite, rubygems usage etc)." if @verbose
+          puts "DEB_BUILD_OPTIONS includes nocheck, skipping all checks (test suite etc)." if @verbose
           @skip_checks = true
         else
           @skip_checks = false
@@ -163,37 +159,10 @@ module Gem2Deb
       @skip_checks
     end
 
-    def packages
-      @packages ||=
-        begin
-          packages = []
-          multibinary = false
-          File.readlines('debian/control').select do |line|
-            if line =~ /^Package:\s*(\S*)\s*$/
-              package = $1
-              packages.push({ :binary_package => package })
-            elsif line =~ /^X-DhRuby-Root:\s*(\S*)\s*$/
-              root = $1
-              if packages.last
-                packages.last[:root] = root
-              end
-              multibinary = true
-            end
-          end
-          if multibinary
-            packages.select { |p| p[:root] }
-          else
-            package = packages.first
-            package[:root] = '.'
-            [package]
-          end
-        end
-    end
-
     def installers
       @installers ||=
         begin
-          packages.map do |package|
+          @source.packages.map do |package|
             installer_class.new(
               package[:binary_package],
               package[:root],
