@@ -2,6 +2,12 @@ unless ENV['ADTTMP']
   $LOAD_PATH.unshift File.expand_path('../../lib', __FILE__)
 end
 
+if Kernel.const_defined?('SimpleCov')
+  SimpleCov.start do
+    add_filter %r{/test/}
+    minimum_coverage 83
+  end
+end
 
 require 'test/unit'
 require 'shoulda-context'
